AsyncFn

Trait AsyncFn 

1.85.0 · Source
pub trait AsyncFn<Args: Tuple>: AsyncFnMut<Args> {
    // Required method
    extern "rust-call" fn async_call(
        &self,
        args: Args,
    ) -> Self::CallRefFuture<'_>;
}
An async-aware version of the Fn trait.

All async fn and functions returning futures implement this trait.

Required Methods

extern "rust-call" fn async_call( &self, args: Args, ) -> Self::CallRefFuture<'_>

🔬This is a nightly-only experimental API. (async_fn_traits)

Call the AsyncFn, returning a future which may borrow from the called closure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.85.0 · Source

impl<A: Tuple, F> AsyncFn<A> for &F
where F: AsyncFn<A> + ?Sized,

Source

impl<F, Args> AsyncFn<Args> for SyncView<F>
where F: Sync + AsyncFn<Args>, Args: Tuple,